var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import axios from "axios";
import { Auth } from "./auth.js";
import { ObjectSerializer } from "../api.js";
import { defaultEnvironmentConfig } from "../configurations/environments.js";
export class SubscriptionsClient {
    constructor(config) {
        this.config = config;
        this.environmentConfig = defaultEnvironmentConfig[this.config.environment];
        this.subscriptionsUrl = this.environmentConfig.apiBaseUrl + "/Subscriptions";
        this.auth = new Auth({
            audience: this.environmentConfig.oauthAudience,
            clientId: config.clientId,
            clientSecret: config.clientSecret,
            scopes: config.scopes,
            tokenUrl: this.environmentConfig.tokenUrl,
            customOptions: config.customOptions
        });
        this.httpClient = axios.create({
            validateStatus: () => true
        });
    }
    subscribe(data) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = this.subscriptionsUrl;
            const res = yield this.httpClient.post(url, ObjectSerializer.serialize(data, "SubscribeRequestData"), {
                headers: yield this.auth.getHeaders(),
            });
            if (res.status === 200) {
                return res.data;
            }
            else {
                throw new Error(res.data);
            }
        });
    }
    deleteSubscription(subscriptionName) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = `${this.subscriptionsUrl}/${subscriptionName}`;
            const res = yield this.httpClient.delete(url, {
                headers: yield this.auth.getHeaders(),
            });
            if (res.status !== 200) {
                throw new Error(res.data);
            }
        });
    }
}
